@@ -8,8 +8,7 @@ from networktools.library import my_random_string
 from networktools.colorprint import gprint, bprint, rprint
 
 # same module
-from .taskloop import coromask, renew, simple_fargs, simple_fargs_out
-from networktools.factory import FactoryClass
+from .taskloop import TaskLoop
 
 
 class TaskScheduler:
@@ -214,7 +213,7 @@ class TaskScheduler:
                 return ipt
         return None
 
-    async def process_sta_manager(self, ipt):
+    async def process_sta_manager(self, ipt, *args, **kwargs):
         """
         Manage asignation of station to task inside ipt process
 
@@ -231,7 +230,7 @@ class TaskScheduler:
                         self.assigned_tasks[ipt].update({ico: ids})
                         break
         await asyncio.sleep(1)
-        return [ipt], {}
+        return [ipt, *args], kwargs
 
     def set_pst(self, ids, args, kwargs):
         """
@@ -310,28 +309,18 @@ class TaskScheduler:
             nd = {ico:  None}
             new_dict.update(nd)
         self.assigned_tasks[ipt] = new_dict
-        bprint(f"Tareas asignada {new_dict}")
         tasks_on_this_ipt = self.assigned_tasks.get(ipt)
         stax, sta_kwargs = self.set_init_args_kwargs(ipt)
-        bprint(f"ipt {ipt} Args inputy {stax}")
-        rprint(f"ipt {ipt} kwargs input {sta_kwargs}")
         for ico in tasks_on_this_ipt.keys():
             if self.run_task:
                 try:
                     args = [ipt, ico, *stax]
-                    task = loop.create_task(
-                        coromask(
-                            self.process_sta_task,
-                            args, sta_kwargs,
-                            simple_fargs_out)
-                    )
-                    task.add_done_callback(
-                        functools.partial(renew,
-                                          task,
-                                          self.process_sta_task,
-                                          simple_fargs_out)
-                    )
-                    tasks.append(task)
+                    task_1 = TaskLoop(
+                        self.process_sta_task,
+                        args,
+                        sta_kwargs,
+                        **{"name": "process_sta_task"})
+                    tasks.append(task_1)
                 except Exception as ex:
                     print(
                         "Error en collect_task, gather stations, process_sta(task) %s, error %s"
@@ -344,21 +333,15 @@ class TaskScheduler:
                 if self.n2s:
                     self.n2s_coro = self.n2s.get('coro')
                     n2s_args = self.n2s.get('args')
+                    n2s_kwargs = self.n2s.get('kwargs')
                     n2s_args.insert(0, ipt)
                     args = [ipt, ico, *n2s_args]
-                    task = loop.create_task(
-                        coromask(
-                            self.process_sta_task_n2s,
-                            args,
-                            simple_fargs_out)
-                    )
-                    task.add_done_callback(
-                        functools.partial(renew,
-                                          task,
-                                          self.process_sta_task_n2s,
-                                          simple_fargs_out)
-                    )
-                    tasks.append(task)
+                    task_2 = TaskLoop(
+                        self.n2s,
+                        n2s_args,
+                        n2s_kwargs,
+                        {"name": "task_n2s"})
+                    tasks.append(task_2)
             except Exception as ex:
                 print(
                     "Error en collect_task, gather stations, net2service(task) %s, error %s"
@@ -370,21 +353,15 @@ class TaskScheduler:
                 if self.s2n:
                     self.s2n_coro = self.s2n.get('coro')
                     s2n_args = self.s2n.get('args')
+                    s2n_kwargs = self.s2n.get('args')
                     s2n_args.insert(0, ipt)
                     args = [ipt, ico, *s2n_args]
-                    task = loop.create_task(
-                        coromask(
-                            self.process_sta_task_s2n,
-                            args,
-                            simple_fargs_out)
-                    )
-                    task.add_done_callback(
-                        functools.partial(renew,
-                                          task,
-                                          self.process_sta_task_s2n,
-                                          simple_fargs_out)
-                    )
-                    tasks.append(task)
+                    task_3 = TaskLoop(
+                        self.s2n,
+                        s2n_args,
+                        s2n_kwargs,
+                        {"name": "task_s2n"})
+                    tasks.append(task_3)
             except Exception as exe:
                 print(
                     "Error en collect_task, gather stations, service2net(task) %s, error %s"
@@ -394,19 +371,16 @@ class TaskScheduler:
         try:
             args = [ipt]
             kwargs = {}
-            task = loop.create_task(
-                coromask(
-                    self.process_sta_manager,
-                    args, kwargs,
-                    simple_fargs_out)
+            task_4 = TaskLoop(
+                self.process_sta_manager,
+                args,
+                kwargs,
+                {"name": "task_process_sta_manager"}
             )
-            task.add_done_callback(
-                functools.partial(renew,
-                                  task,
-                                  self.process_sta_manager,
-                                  simple_fargs_out)
-            )
-            tasks.append(task)
+            tasks.append(task_4)
+            for task in tasks:
+                bprint(f"Iniciando tarea->{task}")
+                task.create()
         except Exception as exe:
             print("Error en collect_task, manager %s, error %s" % (ipt, exe))
             print(exe)
